@@ -2,9 +2,9 @@
  *
  *  $RCSfile: breakiteratorImpl.cxx,v $
  *
- *  $Revision: 1.11 $
+ *  $Revision: 1.11.42.1 $
  *
- *  last change: $Author: vg $ $Date: 2003/04/24 11:05:06 $
+ *  last change: $Author: vg $ $Date: 2004/10/12 09:36:29 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -399,14 +399,40 @@ static ScriptTypeList typeList[] = {
     { UnicodeScript_kCombiningDiacritical,	ScriptType::LATIN },		// 6,
     { UnicodeScript_kGreek,			ScriptType::LATIN }, 		// 7,
     { UnicodeScript_kCyrillic,			ScriptType::LATIN }, 		// 8,
+    { UnicodeScript_kArmenian,			ScriptType::LATIN }, 		// 9,
 
     { UnicodeScript_kHebrew, 			ScriptType::COMPLEX },		// 10,
     { UnicodeScript_kArabic, 			ScriptType::COMPLEX },		// 11,
+    { UnicodeScript_kSyriac, 			ScriptType::COMPLEX },		// 12,
+    { UnicodeScript_kThaana, 			ScriptType::COMPLEX },		// 13,
     { UnicodeScript_kDevanagari,		ScriptType::COMPLEX },		// 14,
+    { UnicodeScript_kBengali,		ScriptType::COMPLEX },		// 15,
+    { UnicodeScript_kGurmukhi,		ScriptType::COMPLEX },		// 16,
+    { UnicodeScript_kGujarati,		ScriptType::COMPLEX },		// 17,
+    { UnicodeScript_kOriya,		ScriptType::COMPLEX },		// 18,
+    { UnicodeScript_kTamil,		ScriptType::COMPLEX },		// 19,
+    { UnicodeScript_kTelugu,		ScriptType::COMPLEX },		// 20,
+    { UnicodeScript_kKannada,		ScriptType::COMPLEX },		// 21,
+    { UnicodeScript_kMalayalam,		ScriptType::COMPLEX },		// 22,
+    { UnicodeScript_kSinhala,		ScriptType::COMPLEX },		// 23,
     { UnicodeScript_kThai,			ScriptType::COMPLEX },		// 24,
+    { UnicodeScript_kLao,		ScriptType::COMPLEX },		// 25,
+    { UnicodeScript_kTibetan,			ScriptType::COMPLEX },		// 26,
+    { UnicodeScript_kMyanmar,			ScriptType::COMPLEX },		// 27,
+    { UnicodeScript_kGeorgian,			ScriptType::LATIN },		// 28,
+    { UnicodeScript_kHangulJamo,			ScriptType::ASIAN },		// 29,
+    
+    { UnicodeScript_kEthiopic,			ScriptType::LATIN },		// 30,
+    { UnicodeScript_kCherokee,			ScriptType::LATIN },		// 31,
+    { UnicodeScript_kUnifiedCanadianAboriginalSyllabics,			ScriptType::LATIN },		// 32,
+    { UnicodeScript_kOgham,			ScriptType::LATIN },		// 33,
+    { UnicodeScript_kRunic,			ScriptType::LATIN },		// 34,
 
-    { UnicodeScript_kTibetan,			ScriptType::LATIN },		// 26,
+    { UnicodeScript_kKhmer,			ScriptType::COMPLEX },		// 35,
+    { UnicodeScript_kMongolian,			ScriptType::COMPLEX },		// 36,
 
+    { UnicodeScript_kLatinExtendedAdditional,		ScriptType::LATIN },		// 37,
+    { UnicodeScript_kGreekExtended,		ScriptType::LATIN },		// 38,
     { UnicodeScript_kCJKRadicalsSupplement,	ScriptType::ASIAN },		// 57,
     { UnicodeScript_kKangxiRadicals,		ScriptType::ASIAN },		// 58,
     { UnicodeScript_kIdeographicDescriptionCharacters, ScriptType::ASIAN },	// 59,
@@ -425,9 +451,11 @@ static ScriptTypeList typeList[] = {
     { UnicodeScript_kYiRadicals, 		ScriptType::ASIAN },		// 72,
     { UnicodeScript_kHangulSyllable, 		ScriptType::ASIAN },		// 73,
     { UnicodeScript_kCJKCompatibilityIdeograph, ScriptType::ASIAN },		// 78,
+    { UnicodeScript_kArabicPresentationA, 	ScriptType::COMPLEX },		// 80,
     { UnicodeScript_kCombiningHalfMark, 	ScriptType::ASIAN },		// 81,
     { UnicodeScript_kCJKCompatibilityForm, 	ScriptType::ASIAN },		// 82,
     { UnicodeScript_kSmallFormVariant, 		ScriptType::ASIAN },		// 83,
+    { UnicodeScript_kArabicPresentationB, 		ScriptType::COMPLEX },		// 84,
     { UnicodeScript_kHalfwidthFullwidthForm,	ScriptType::ASIAN },		// 86,
 
     { UnicodeScript_kScriptCount, 		ScriptType::WEAK }		// 88
