@@ -2,9 +2,9 @@
  *
  *  $RCSfile: xmlimprt.cxx,v $
  *
- *  $Revision: 1.87.68.1 $
+ *  $Revision: 1.87.68.2 $
  *
- *  last change: $Author: hr $ $Date: 2004/01/09 14:41:02 $
+ *  last change: $Author: vg $ $Date: 2005/06/16 14:56:10 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -346,12 +346,13 @@ static __FAR_DATA SvXMLTokenMapEntry aContentValidationElemTokenMap[] =
 	{ XML_NAMESPACE_TABLE, XML_HELP_MESSAGE,	XML_TOK_CONTENT_VALIDATION_ELEM_HELP_MESSAGE	},
 	{ XML_NAMESPACE_TABLE, XML_ERROR_MESSAGE,	XML_TOK_CONTENT_VALIDATION_ELEM_ERROR_MESSAGE	},
 	{ XML_NAMESPACE_TABLE, XML_ERROR_MACRO, 	XML_TOK_CONTENT_VALIDATION_ELEM_ERROR_MACRO		},
+	{ XML_NAMESPACE_OFFICE, XML_EVENTS, 	    XML_TOK_CONTENT_VALIDATION_ELEM_EVENTS		    },
 	XML_TOKEN_MAP_END
 };
 
 static __FAR_DATA SvXMLTokenMapEntry aContentValidationAttrTokenMap[] =
 {
-	{ XML_NAMESPACE_TABLE, XML_NAME,				XML_TOK_CONTENT_VALIDATION_NAME					},
+	{ XML_NAMESPACE_TABLE, XML_NAME,				XML_TOK_VALIDATION_NAME					},
 	{ XML_NAMESPACE_TABLE, XML_CONDITION,			XML_TOK_CONTENT_VALIDATION_CONDITION			},
 	{ XML_NAMESPACE_TABLE, XML_BASE_CELL_ADDRESS,	XML_TOK_CONTENT_VALIDATION_BASE_CELL_ADDRESS	},
 	{ XML_NAMESPACE_TABLE, XML_ALLOW_EMPTY_CELL,	XML_TOK_CONTENT_VALIDATION_ALLOW_EMPTY_CELL		},
@@ -498,7 +499,7 @@ static __FAR_DATA SvXMLTokenMapEntry aTableRowCellTokenMap[] =
 static __FAR_DATA SvXMLTokenMapEntry aTableRowCellAttrTokenMap[] =
 {
 	{ XML_NAMESPACE_TABLE, XML_STYLE_NAME,						XML_TOK_TABLE_ROW_CELL_ATTR_STYLE_NAME				},
-	{ XML_NAMESPACE_TABLE, XML_CONTENT_VALIDATION_NAME, 		XML_TOK_TABLE_ROW_CELL_ATTR_CONTENT_VALIDATION_NAME	},
+	{ XML_NAMESPACE_TABLE, XML_VALIDATION_NAME, 		        XML_TOK_TABLE_ROW_CELL_ATTR_VALIDATION_NAME	        },
 	{ XML_NAMESPACE_TABLE, XML_NUMBER_ROWS_SPANNED,  			XML_TOK_TABLE_ROW_CELL_ATTR_SPANNED_ROWS			},
 	{ XML_NAMESPACE_TABLE, XML_NUMBER_COLUMNS_SPANNED,			XML_TOK_TABLE_ROW_CELL_ATTR_SPANNED_COLS			},
 	{ XML_NAMESPACE_TABLE, XML_NUMBER_MATRIX_COLUMNS_SPANNED,   XML_TOK_TABLE_ROW_CELL_ATTR_SPANNED_MATRIX_COLS		},
