@@ -2,9 +2,9 @@
  *
  *  $RCSfile: sclib.cxx,v $
  *
- *  $Revision: 1.25.122.1 $
+ *  $Revision: 1.25.122.2 $
  *
- *  last change: $Author: vg $ $Date: 2004/04/02 12:25:44 $
+ *  last change: $Author: vg $ $Date: 2005/07/01 13:22:51 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -58,7 +58,6 @@
  *
  *
  ************************************************************************/
-
 #pragma hdrstop
 
 #define _SCALC_EXE
@@ -483,17 +482,35 @@ ULONG __EXPORT ScDLL::DetectFilter( SfxMedium& rMedium, const SfxFilter** ppFilt
 		if ( ( pStorage->IsContained( aStreamName ) && pStorage->IsStream( aStreamName ) ) ||
 			 ( pStorage->IsContained( aOldXML ) && pStorage->IsStream( aOldXML ) ) )
 		{
-			//	#85794# don't accept other applications' xml formats,
-			//	recognized by clipboard id
-			ULONG nStorageFormat = pStorage->GetFormat();
-			if ( nStorageFormat == 0 || nStorageFormat == SOT_FORMATSTR_ID_STARCALC_60 )
-			{
-				//	if XML template is set, don't modify
-				if (!lcl_IsAnyXMLFilter(*ppFilter))
+            rtl::OUString sMediaType;
+            com::sun::star::uno::Any aAny;
+            pStorage->GetProperty(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MediaType")), aAny);
+            if ((aAny >>= sMediaType) && (sMediaType.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("application/vnd.oasis.opendocument.spreadsheet"))) ||
+                                        (sMediaType.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("application/vnd.oasis.opendocument.spreadsheet-template")))) 
+            {
+                if ((*ppFilter)->GetFilterName().EqualsAscii("calc8") || (*ppFilter)->GetFilterName().EqualsAscii("calc8_template"))
+                    return ERRCODE_NONE;
+                else
+                {
 					*ppFilter = SFX_APP()->GetFilter( ScDocShell::Factory(),
-													  String::CreateFromAscii(pFilterXML) );
-				return ERRCODE_NONE;
-			}
+													String::CreateFromAscii("calc8") );
+				    return ERRCODE_NONE;
+                }
+            }
+            else
+            {
+                //	#85794# don't accept other applications' xml formats,
+			    //	recognized by clipboard id
+			    ULONG nStorageFormat = pStorage->GetFormat();
+			    if ( nStorageFormat == 0 || nStorageFormat == SOT_FORMATSTR_ID_STARCALC_60 )
+			    {
+				    //	if XML template is set, don't modify
+				    if (!lcl_IsAnyXMLFilter(*ppFilter))
+					    *ppFilter = SFX_APP()->GetFilter( ScDocShell::Factory(),
+													    String::CreateFromAscii(pFilterXML) );
+				    return ERRCODE_NONE;
+			    }
+            }
 		}
 	}
 	else 	// no storage
