@@ -2,9 +2,9 @@
  *
  *  $RCSfile: fecopy.cxx,v $
  *
- *  $Revision: 1.17 $
+ *  $Revision: 1.17.52.1 $
  *
- *  last change: $Author: vg $ $Date: 2003/07/11 12:23:07 $
+ *  last change: $Author: vg $ $Date: 2005/04/29 15:43:24 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -1209,7 +1209,8 @@ void SwFEShell::Paste( SvStream& rStrm, USHORT nAction, const Point* pPt )
 	SdrView *pView = Imp()->GetDrawView();
 
 	//Drop auf bestehendes Objekt: Objekt ersetzen oder neu Attributieren.
-	if( 1 == pModel->GetPage(0)->GetObjCount() &&
+	if( pModel->GetPageCount() > 1 &&
+		1 == pModel->GetPage(0)->GetObjCount() &&
 		1 == pView->GetMarkList().GetMarkCount() )
 	{
         // OD 10.07.2003 #110742# - replace a marked 'virtual' drawing object
