@@ -2,9 +2,9 @@
  *
  *  $RCSfile: txtfly.cxx,v $
  *
- *  $Revision: 1.36 $
+ *  $Revision: 1.36.70.1 $
  *
- *  last change: $Author: vg $ $Date: 2003/07/04 13:24:57 $
+ *  last change: $Author: vg $ $Date: 2004/10/06 14:55:36 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -1331,8 +1331,10 @@ sal_Bool SwTxtFly::GetTop( const SdrObject *pNew, const sal_Bool bInFtn,
 					aPos = pNew->GetBoundRect().TopLeft();
 				pTmp = GetVirtualUpper( pTmp, aPos );
 			}
-			if( pCurrFrm->GetNext() != pTmp &&
+            // --> FME 2004-09-06 #i33577# Robust: Check for valid pTmp.
+            if( pTmp && pCurrFrm->GetNext() != pTmp &&
 				IsFrmInSameKontext( pTmp, pCurrFrm ) )
+            // <--
 			{
 				if( FLY_AT_FLY == rNewA.GetAnchorId() ) // LAYER_IMPL
 					return sal_True;  // Rahmengebundenen ausweichen.
