@@ -2,9 +2,9 @@
  *
  *  $RCSfile: untbl.cxx,v $
  *
- *  $Revision: 1.7 $
+ *  $Revision: 1.7.160.1 $
  *
- *  last change: $Author: vg $ $Date: 2003/04/17 16:10:01 $
+ *  last change: $Author: vg $ $Date: 2004/10/12 09:35:56 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -161,6 +161,9 @@
 #ifndef _FMTANCHR_HXX
 #include <fmtanchr.hxx>
 #endif
+#ifndef _SWREDLINEMODEGUARD_HXX
+#include <SwRedlineModeGuard.hxx>
+#endif
 
 inline SwDoc& SwUndoIter::GetDoc() const { return *pAktPam->GetDoc(); }
 extern void ClearFEShellTabCols();
@@ -2315,42 +2318,6 @@ void SwUndoTblNumFmt::Undo( SwUndoIter& rIter )
 	pPam->GetPoint()->nContent.Assign( pTxtNd, 0 );
 }
 
-/** switch the RedlineMode on the given document, using
- * SetRedlineMode_intern. This class set the mode in the constructor,
- * and changes it back in the destructor, i.e. it uses the
- * initialization-is-resource-acquisition idiom. 
- */
-class RedlineModeInternGuard
-{
-    SwDoc& mrDoc;
-    SwRedlineMode meOldRedlineMode;
-
-public:
-    RedlineModeInternGuard( 
-        SwDoc& rDoc,                      /// change mode of this document
-        SwRedlineMode eNewRedlineMode,    /// new redline mode
-        SwRedlineMode eRedlineModeMask  = /// change only bits set in this mask
-            static_cast<SwRedlineMode> ( REDLINE_ON | REDLINE_IGNORE ) );
-    ~RedlineModeInternGuard();
-};
-
-RedlineModeInternGuard::RedlineModeInternGuard( 
-    SwDoc& rDoc, 
-    SwRedlineMode eNewRedlineMode,
-    SwRedlineMode eRedlineModeMask ) 
-    : mrDoc( rDoc ),
-      meOldRedlineMode( rDoc.GetRedlineMode() )
-{
-    mrDoc.SetRedlineMode_intern( ( meOldRedlineMode & ~eRedlineModeMask ) |
-                                 ( eNewRedlineMode & eRedlineModeMask ) );
-}
-
-RedlineModeInternGuard::~RedlineModeInternGuard()
-{
-    mrDoc.SetRedlineMode_intern( meOldRedlineMode );
-}
-
-
 
 void SwUndoTblNumFmt::Redo( SwUndoIter& rIter )
 {
@@ -2399,7 +2366,9 @@ void SwUndoTblNumFmt::Redo( SwUndoIter& rIter )
         // dvo: When redlining is (was) enabled, setting the attribute
         // will also change the cell content. To allow this, the
         // REDLINE_IGNORE flag must be removed during Redo. #108450#
-        RedlineModeInternGuard aGuard( rDoc, REDLINE_NONE, REDLINE_IGNORE );
+        SwRedlineModeGuard aGuard( rDoc, REDLINE_NONE, 
+                                   &SwDoc::SetRedlineMode_intern, 
+                                   REDLINE_IGNORE );
 		pBoxFmt->SetAttr( aBoxSet );
 	}
 	else if( NUMBERFORMAT_TEXT != nFmtIdx )
@@ -2420,7 +2389,9 @@ void SwUndoTblNumFmt::Redo( SwUndoIter& rIter )
         // dvo: When redlining is (was) enabled, setting the attribute
         // will also change the cell content. To allow this, the
         // REDLINE_IGNORE flag must be removed during Redo. #108450#
-        RedlineModeInternGuard aGuard( rDoc, REDLINE_NONE, REDLINE_IGNORE );
+        SwRedlineModeGuard aGuard( rDoc, REDLINE_NONE,
+                                   &SwDoc::SetRedlineMode_intern,
+                                   REDLINE_IGNORE );
 		pBoxFmt->SetAttr( aBoxSet );
 	}
 	else
