@@ -2,9 +2,9 @@
  *
  *  $RCSfile: vclxaccessibletoolboxitem.cxx,v $
  *
- *  $Revision: 1.36 $
+ *  $Revision: 1.36.22.1 $
  *
- *  last change: $Author: rt $ $Date: 2003/06/12 07:48:55 $
+ *  last change: $Author: vg $ $Date: 2004/10/06 14:52:45 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -212,7 +212,7 @@ VCLXAccessibleToolBoxItem::~VCLXAccessibleToolBoxItem()
 	{
 		sRet = m_pToolBox->GetItemText( m_nItemId );
 //OJ #108243# we only read the name of the toolboxitem
-// 
+//
 //		Window* pItemWindow = m_pToolBox->GetItemWindow( m_nItemId );
 //		if ( pItemWindow && pItemWindow->GetAccessible().is() &&
 //			 pItemWindow->GetAccessible()->getAccessibleContext().is() )
@@ -330,7 +330,20 @@ void VCLXAccessibleToolBoxItem::implGetSelection( sal_Int32& nStartIndex, sal_In
 // -----------------------------------------------------------------------------
 // XInterface
 // -----------------------------------------------------------------------------
-IMPLEMENT_FORWARD_XINTERFACE2( VCLXAccessibleToolBoxItem, AccessibleTextHelper_BASE, VCLXAccessibleToolBoxItem_BASE )
+IMPLEMENT_FORWARD_REFCOUNT( VCLXAccessibleToolBoxItem, AccessibleTextHelper_BASE )
+Any SAL_CALL VCLXAccessibleToolBoxItem::queryInterface( const Type& _rType ) throw (RuntimeException)
+{
+	// --> PB 2004-09-03 #i33611# - toolbox buttons without text don't support XAccessibleText
+	if ( _rType == ::getCppuType( ( const Reference< XAccessibleText >* ) 0 )
+		&& ( !m_pToolBox || m_pToolBox->GetButtonType() == BUTTON_SYMBOL ) )
+		return Any();
+	// <--
+
+	::com::sun::star::uno::Any aReturn = AccessibleTextHelper_BASE::queryInterface( _rType );
+	if ( !aReturn.hasValue() )
+		aReturn = VCLXAccessibleToolBoxItem_BASE::queryInterface( _rType );
+	return aReturn;
+}
 // -----------------------------------------------------------------------------
 // XTypeProvider
 // -----------------------------------------------------------------------------
